inferpy.contextmanager package
==============================

Submodules
----------

inferpy.contextmanager.data\_model module
-----------------------------------------

.. automodule:: inferpy.contextmanager.data_model
   :members:
   :undoc-members:
   :show-inheritance:

inferpy.contextmanager.evidence module
--------------------------------------

.. automodule:: inferpy.contextmanager.evidence
   :members:
   :undoc-members:
   :show-inheritance:

inferpy.contextmanager.randvar\_registry module
-----------------------------------------------

.. automodule:: inferpy.contextmanager.randvar_registry
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: inferpy.contextmanager
   :members:
   :undoc-members:
   :show-inheritance:
